@@ -21,6 +21,7 @@ class blogLib extends Addon
 	private $db;	// DB接続オブジェクト
 	private $blogId = '';	// ブログID
 	private $templateId = '';	// テンプレートID
+	const CF_ENTRY_VIEW_COUNT		= 'entry_view_count';			// 記事表示数
 	
 	/**
 	 * コンストラクタ
@@ -198,7 +199,37 @@ class blogLib extends Addon
 		return true;
 	}
 	/**
-	 * 公開中のエントリー項目を取得。アクセス制限も行う。
+	 * 記事一覧の表示項目数を取得
+	 *
+	 * @return int				表示項目数
+	 */
+	function getPublicContentViewCount()
+	{
+		$itemCount = $this->getConfig(self::CF_ENTRY_VIEW_COUNT);
+		return $itemCount;
+	}
+	/**
+	 * 公開中の記事数を取得。アクセス制限も行う。
+	 *
+	 * @param timestamp $now				現在日時(現在日時より未来の投稿日時の記事は取得しない)
+	 * @param timestamp	$startDt			期間(開始日)
+	 * @param timestamp	$endDt				期間(終了日)
+	 * @param array		$keywords			検索キーワード
+	 * @param string	$langId				言語
+	 * @param int		$categoryId			カテゴリーID(nullのとき指定なし)
+	 * @param string	$blogId				ブログID(nullのとき指定なし)
+	 * @return int							項目数
+	 */
+	function getPublicContentCount($now, $startDt, $endDt, $keywords, $langId, $categoryId = null, $blogId = null)
+	{
+		global $gEnvManager;
+		
+		$userId = $gEnvManager->getCurrentUserId();
+		$itemCount = $this->db->getPublicEntryItemsCount($now, $startDt, $endDt, $keywords, $langId, $userId, $categoryId, $blogId);
+		return $itemCount;
+	}
+	/**
+	 * 公開中の記事を取得。アクセス制限も行う。
 	 *
 	 * @param int		$limit				取得する項目数
 	 * @param int		$page				取得するページ(1～)
@@ -210,15 +241,39 @@ class blogLib extends Addon
 	 * @param string	$langId				言語
 	 * @param int		$order				取得順(0=昇順,1=降順)
 	 * @param function	$callback			コールバック関数
+	 * @param int		$categoryId			カテゴリーID(nullのとき指定なし)
 	 * @param string	$blogId				ブログID(nullのとき指定なし)
 	 * @return 			なし
 	 */
-	function getPublicEntryItems($limit, $page, $entryId, $now, $startDt, $endDt, $keywords, $langId, $order, $callback, $blogId = null)
+	function getPublicContentList($limit, $page, $entryId, $now, $startDt, $endDt, $keywords, $langId, $order, $callback, $categoryId = null, $blogId = null)
 	{
 		global $gEnvManager;
 		
 		$userId = $gEnvManager->getCurrentUserId();
-		$this->db->getPublicEntryItems($limit, $page, $entryId, $now, $startDt, $endDt, $keywords, $langId, $order, $userId, $callback, $blogId);
+		$this->db->getPublicEntryItems($limit, $page, $entryId, $now, $startDt, $endDt, $keywords, $langId, $order, $userId, $callback, $categoryId, $blogId);
+	}
+	/**
+	 * 公開中のエントリーの前後のエントリー項目を取得
+	 *
+	 * @param int       $type				前後記事のタイプ(0=前方,1=後方)
+	 * @param timestamp $regDate			基準となる記事の登録日時
+	 * @param timestamp $now				現在日時(現在日時より未来の投稿日時の記事は取得しない)
+	 * @param timestamp	$startDt			期間(開始日)
+	 * @param timestamp	$endDt				期間(終了日)
+	 * @param array		$keywords			検索キーワード
+	 * @param string	$langId				言語
+	 * @param int		$order				取得順(0=昇順,1=降順)
+	 * @param int		$categoryId			カテゴリーID(nullのとき指定なし)
+	 * @param string	$blogId				ブログID(nullのとき指定なし)
+	 * @return array 						記事のレコード。取得なしの場合はfalseを返す。
+	 */
+	function getPublicPrevNextEntry($type, $regDate, $now, $startDt, $endDt, $keywords, $langId, $order, $categoryId = null, $blogId = null)
+	{
+		global $gEnvManager;
+		
+		$userId = $gEnvManager->getCurrentUserId();
+		$row = $this->db->getPublicPrevNextEntry($type, $regDate, $now, $startDt, $endDt, $keywords, $langId, $order, $userId, $categoryId, $blogId);
+		return $row;
 	}
 }
 ?>
