@@ -122,22 +122,32 @@ class BaseFrameContainer extends Core
 			$errMessage = '';	// エラーメッセージ
 			$messageDetail = '';	// 詳細メッセージ
 			
-			// ページID,ページサブIDからアクセス権をチェック
-			$isPublicUrl = $this->gPage->canAccessUrl($isActivePage, $errCode);
-			if (!$isPublicUrl && !$isSystemManageUser){// システム運用可能ユーザかどうか
+			// ページID,ページサブID以外のURLパラメータをチェック。ページマネージャーでの処理(startPage())の結果を反映。
+			$ret = $this->gPage->isSystemPage();		// システム制御ページへ遷移するかどうか
+			if ($ret){
+				// ページが見つかりません画面へ遷移
 				$canAccess = false;
-				$isErrorAccess = true;		// 不正アクセスかどうか
-				$errMessage = 'ユーザに公開されていないページへのアクセス。';
+				$toAdminType = 4;
+			}
+			
+			// ページID,ページサブIDからアクセス権をチェック
+			if ($canAccess){
+				$isPublicUrl = $this->gPage->canAccessUrl($isActivePage, $errCode);
+				if (!$isPublicUrl && !$isSystemManageUser){// システム運用可能ユーザかどうか
+					$canAccess = false;
+					$isErrorAccess = true;		// 不正アクセスかどうか
+					$errMessage = 'ユーザに公開されていないページへのアクセス。';
 				
-				if (!$isActivePage){
-					if ($errCode == 1){			// ページIDが不正な場合
-						$toAdminType = 4;
-					} else {
-						$toAdminType = 3;		// 有効なアクセスポイント、ページでない場合は存在しないページとする
+					if (!$isActivePage){
+						if ($errCode == 1){			// ページIDが不正な場合
+							$toAdminType = 4;
+						} else {
+							$toAdminType = 3;		// 有効なアクセスポイント、ページでない場合は存在しないページとする
+						}
 					}
 				}
 			}
-
+			
 			// ################### ユーザアクセス制御 ######################
 			// クッキーがないため権限を識別できない場合でも、管理者として処理する場合があるので、サブクラスの_checkAccess()メソッドは必ず通るようにする
 			if ($canAccess){		// アクセス可能な場合はユーザをチェック
@@ -663,7 +673,7 @@ class BaseFrameContainer extends Core
 		if (method_exists($this, '_preBuffer')) $this->_preBuffer($request);
 	
 		if ($convType == 100){		// WordPressテンプレートのとき
-			// WordPress用定義値
+			// WordPress用ベース定義値
 			define('WPINC', 'wp-includes');
 			define('ABSPATH', $this->gEnv->getWordpressRootPath() . '/' );
 			define('TEMPLATEPATH', $this->gEnv->getTemplatesPath() . '/' . $curTemplate);
@@ -682,9 +692,13 @@ class BaseFrameContainer extends Core
 			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/default-filters.php');
 			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/l10n.php');
 			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/class-wp.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/class-wp-user.php');
 			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/class-wp-walker.php');
-			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/class-wp-query.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/class-wp-query.php');				// コンテンツデータ取得
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/class-wp-comment-query.php');
 			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/class-walker-page.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/class-wp-theme.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/class-wp-list-util.php');
 //			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/class-walker-nav-menu.php');
 //			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/class-wp-dependency.php');
 			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/class-wp-post.php');			// コンテンツAPIマネージャーからWP_Post型でデータを取得
@@ -694,6 +708,7 @@ class BaseFrameContainer extends Core
 			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/post.php');
 			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/user.php');
 			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/widgets.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/comment.php');
 			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/http.php');
 			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/kses.php');
 			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/script-loader.php');
@@ -718,20 +733,17 @@ class BaseFrameContainer extends Core
 //			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/option.php');
 			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/pomo/translations.php');
 			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/pomo/mo.php');
-
-			// テンプレート内のファイルを読み込む
-			if ( file_exists(TEMPLATEPATH . '/functions.php')) include(TEMPLATEPATH . '/functions.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/capabilities.php');
+			require_once($this->gEnv->getWordpressRootPath() . '/wp-includes/meta.php');
 		
 			// Magic3用インターフェイス
+			require_once($this->gEnv->getWordpressRootPath() . '/wpInit.php');		// 初期値取得
 			require_once($this->gEnv->getWordpressRootPath() . '/contentApi.php');	// コンテンツ取得API
 			require_once($this->gEnv->getWordpressRootPath() . '/menuApi.php');		// メニュー情報取得API
-			require_once($this->gEnv->getWordpressRootPath() . '/wpInit.php');		// 初期値設定
-			
 
 			// ##### データ初期化 #####
-			wp_initial_constants();			// 定義値取得
-			m3WpInit();						// Magic3用インターフェイス初期化。$GLOBALS['m3WpOptions']を初期化し、get_option()はここから使用可能にする。
-
+			wp_initial_constants();			// WordPressその他定義値設定
+			
 			// プラグイン初期化
 			$GLOBALS['wp_plugin_paths'] = array();			// $wp_plugin_pathsは未使用?
 			foreach (wp_get_active_and_valid_plugins() as $plugin) {// プラグインロード
@@ -741,17 +753,19 @@ class BaseFrameContainer extends Core
 			unset($plugin);
 
 			// WordPressメインオブジェクト作成
-			$GLOBALS['locale'] = $this->gEnv->getCurrentLanguage();
-			$GLOBALS['wp'] = new WP();
+			$GLOBALS['locale'] = $this->gEnv->getCurrentLanguage();		// 表示言語を設定
 			$GLOBALS['wp_the_query'] = new WP_Query();
 			$GLOBALS['wp_query'] = $GLOBALS['wp_the_query'];
+			$GLOBALS['wp'] = new WP();
 			$GLOBALS['gContentApi'] = new contentApi();			// Magic3コンテンツAPIオブジェクト
 			$GLOBALS['gMenuApi'] = new menuApi();			// Magic3メニュー情報APIオブジェクト
 			
-			// 初期処理
+			// テンプレート初期処理
 			do_action('setup_theme');
-			load_default_textdomain();
-			do_action('after_setup_theme');
+			load_default_textdomain();			// 言語リソースを読み込む
+			m3WpInit();							// 言語リソース読み込み後にMagic3用インターフェイス初期化。$GLOBALS['m3WpOptions']を初期化し、get_option()はここから使用可能にする。
+			if ( file_exists(TEMPLATEPATH . '/functions.php')) include(TEMPLATEPATH . '/functions.php');// テンプレート初期処理
+			do_action('after_setup_theme');		// wp-multibyte-patchプラグイン読み込み
 			do_action('wp_loaded');
 			
 			// ##### 起動PHPファイル取得。データ取得用パラメータ設定。#####
@@ -766,7 +780,8 @@ class BaseFrameContainer extends Core
 			switch ($contentType){
 			case M3_VIEW_TYPE_CONTENT:		// 汎用コンテンツ
 				if ($firstKey == M3_REQUEST_PARAM_CONTENT_ID || $firstKey == M3_REQUEST_PARAM_CONTENT_ID_SHORT){	// コンテンツIDのとき
-					$defaultIndexFile = get_page_template();		// 固定ページテンプレート
+					// フルパスで返るので相対パスに修正
+					$defaultIndexFile = $this->_getRelativeTemplateIndexPath($curTemplate, get_page_template());		// 固定ページテンプレート
 					
 					// コンテンツID設定
 					$firstValue = $this->gRequest->trimValueOf($firstKey);
@@ -781,7 +796,8 @@ class BaseFrameContainer extends Core
 //				if ($firstKey == M3_REQUEST_PARAM_BLOG_ID || $firstKey == M3_REQUEST_PARAM_BLOG_ID_SHORT ||			// ブログIDのとき
 //					$firstKey == M3_REQUEST_PARAM_BLOG_ENTRY_ID || $firstKey == M3_REQUEST_PARAM_BLOG_ENTRY_ID_SHORT){		// ブログ記事IDのとき
 				if ($firstKey == M3_REQUEST_PARAM_BLOG_ENTRY_ID || $firstKey == M3_REQUEST_PARAM_BLOG_ENTRY_ID_SHORT){		// ブログ記事IDのとき
-					$defaultIndexFile = get_single_template();		// 記事詳細テンプレート
+					// フルパスで返るので相対パスに修正
+					$defaultIndexFile = $this->_getRelativeTemplateIndexPath($curTemplate, get_single_template());		// 記事詳細テンプレート
 					
 					// コンテンツID設定
 					$firstValue = $this->gRequest->trimValueOf($firstKey);
@@ -798,7 +814,8 @@ class BaseFrameContainer extends Core
 				break;
 			default:
 				// コンテンツタイプが設定されていないページに場合は、固定ページ用のテンプレートを使用
-				$defaultIndexFile = get_page_template();		// 固定ページテンプレート
+				// フルパスで返るので相対パスに修正
+				$defaultIndexFile = $this->_getRelativeTemplateIndexPath($curTemplate, get_page_template());		// 固定ページテンプレート
 				break;
 			}
 			
@@ -876,7 +893,7 @@ class BaseFrameContainer extends Core
 			require_once($templateIndexFile);
 		} else {		// テンプレートが存在しないとき
 			if ($this->gEnv->isSystemManageUser()){		// システム管理ユーザのとき
-				echo 'template not found error: ' . $curTemplate;
+				echo 'template not found error: ' . $curTemplate . ', path=' . $templateIndexFile;
 			} else {
 				// 一般向けにはメンテナンス画面を表示
 				$this->gPage->setSystemHandleMode(10/*サイト非公開中*/);
@@ -1239,5 +1256,22 @@ class BaseFrameContainer extends Core
 			$this->_script[strtolower($type)] .= chr(13).$content;
 		}
 	}
+	/**
+	 * WordPressテンプレートの起動ファイルパスを相対パスに変換
+	 *
+	 * @param string $templateId	テンプレートID
+	 * @param string $path			テンプレートの起動ファイル絶対パス
+	 * @return string				テンプレート内での相対パス。エラー発生の場合はデフォルト(index.php)を返す。
+	 */
+	function _getRelativeTemplateIndexPath($templateId, $path)
+	{
+		$savedPath = $path;
+		$templatePath = $this->gEnv->getTemplatesPath() . '/' . $templateId . '/';
+		
+		// テンプレートまでのパスを削除
+		$path = str_replace($templatePath, '', $path);
+		if ($path == $savedPath) $path = 'index.php';
+		return $path;
+	}
 }
 ?>
