@@ -23,6 +23,7 @@ class AccessManager extends Core
 	private $_oldSessionId;				// 古いセッションID
 	private $_accessLogSerialNo;		// アクセスログのシリアルNo
 	private $_useAutoLogin;				// 自動ログイン機能を使用するかどうか
+	private $_sessionCode;				// セッションセキュリティチェック用
    	const LOG_REQUEST_PARAM_MAX_LENGTH	= 1024;				// ログに保存するリクエストパラメータの最大長
 	const PASSWORD_LENGTH = 8;		// パスワード長
 	const SEND_PASSWORD_FORM = 'send_tmp_password';		// 仮パスワード送信用フォーム
@@ -118,11 +119,11 @@ class AccessManager extends Core
 		if ($retValue){
 			// ユーザログインログを残す
 			$this->gOpeLog->writeUserInfo(__METHOD__, 'ユーザがログインしました。アカウント: ' . $account, 2300,
-											'account=' . $account . ', passward=' . $password . ', userid=' . $this->gEnv->getCurrentUserId() . ', IP=' . $this->_clientIp, 'account=' . $account/*検索補助データ*/);
+											'account=' . $account . ', passward=' . $password . ', userid=' . $this->gEnv->getCurrentUserId() . ', IP=' . $this->getClientIp(), 'account=' . $account/*検索補助データ*/);
 		} else {
 			// ユーザエラーログを残す
 			$this->gOpeLog->writeUserError(__METHOD__, 'ユーザがログインに失敗しました。アカウント: ' . $account, 2310,
-											'account=' . $account . ', passward=' . $password . ', IP=' . $this->_clientIp, 'account=' . $account/*検索補助データ*/);
+											'account=' . $account . ', passward=' . $password . ', IP=' . $this->getClientIp(), 'account=' . $account/*検索補助データ*/);
 			
 			// 入力アカウントを保存
 			//$this->db->addErrorLoginLog($account, $accessIp, $this->_accessLogSerialNo);
@@ -143,7 +144,7 @@ class AccessManager extends Core
 		
 		$now = date("Y/m/d H:i:s");	// 現在日時
 		$accessIp = $gRequestManager->trimServerValueOf('REMOTE_ADDR');		// アクセスIP
-				
+		
 		// ユーザチェックが必要な場合は承認済みユーザのみ許可する
 		if (($checkUser && $row['lu_user_type'] >= 0 && $row['lu_enable_login'] &&
 			$this->_isActive($row['lu_active_start_dt'], $row['lu_active_end_dt'], $now)) || // 承認済みユーザ、ログイン可能
@@ -152,6 +153,13 @@ class AccessManager extends Core
 			// ログインした場合はセッションIDを変更する
 			$this->setOldSessionId(session_id());		// 古いセッションIDを保存
 			session_regenerate_id(true);
+			
+			// 新規のセッションにセキュリティコードを設定
+			$gRequestManager->setSessionValue(M3_SESSION_CODE, $this->getSessionSecurityCode());
+			$gRequestManager->setSessionValue(M3_SESSION_CLIENT_IP, $this->getClientIp());
+			
+			// Nodejs連携用データ
+			$gRequestManager->setSessionValue(M3_SESSION_USER_ID, $row['lu_id']);		// ユーザID
 	
 			// ユーザ情報オブジェクトを作成
 			$userInfo = new UserInfo();
@@ -430,9 +438,8 @@ class AccessManager extends Core
 	{
 		global $gRequestManager;
 		global $gEnvManager;
-		global $gAccessManager;
 		global $gInstanceManager;
-		
+
 		// ユーザ情報が存在しているときは、ユーザIDを登録する
 		$userId = 0;
 		$userInfo = $gEnvManager->getCurrentUserInfo();
@@ -441,8 +448,7 @@ class AccessManager extends Core
 		}
 		$cookieVal	= isset($this->_clientId) ? $this->_clientId : '';			// アクセス管理用クッキー
 		$session	= session_id();				// セッションID
-		//$ip			= $gRequestManager->trimServerValueOf('REMOTE_ADDR');		// クライアントIP
-		$this->_clientIp	= $this->_getClientIp($gRequestManager);		// クライアントIP
+		$clientIp	= $this->getClientIp();		// クライアントIP
 		$method		= $gRequestManager->trimServerValueOf('REQUEST_METHOD');	// アクセスメソッド
 		$uri		= $gRequestManager->trimServerValueOf('REQUEST_URI');
 		$referer	= $gRequestManager->trimServerValueOf('HTTP_REFERER');
@@ -466,7 +472,7 @@ class AccessManager extends Core
 		$isCmd = !empty($cmd);			// コマンド実行かどうか
 		
 		// アクセスログのシリアルNoを保存
-		$this->_accessLogSerialNo = $this->db->accessLog($userId, $cookieVal, $session, $this->_clientIp, $method, $uri, $referer, $request, $agent, $language, $path, $isCookie, $isCrawler, $isCmd);
+		$this->_accessLogSerialNo = $this->db->accessLog($userId, $cookieVal, $session, $clientIp, $method, $uri, $referer, $request, $agent, $language, $path, $isCookie, $isCrawler, $isCmd);
 		
 		// ##### 即時アクセス解析 #####
 		if (M3_SYSTEM_REALTIME_ANALYTICS) $gInstanceManager->getAnalyzeManager()->realtimeAnalytics($this->_accessLogSerialNo, $cookieVal);
@@ -478,6 +484,9 @@ class AccessManager extends Core
 	 */
 	function getClientIp()
 	{
+		global $gRequestManager;
+		
+		if (!isset($this->_clientIp)) $this->_clientIp	= $this->_getClientIp($gRequestManager);		// クライアントIP
 		return $this->_clientIp;
 	}
 	/**
@@ -498,6 +507,76 @@ class AccessManager extends Core
 		}
 		return $remoteIp;
 	}
+	/**
+	 * セッションセキュリティチェック
+	 *
+	 * @param object  $userInfo		ユーザ情報
+	 * @return bool					true=問題なし、false=問題あり
+	 */
+	function checkSessionSecurity($userInfo)
+	{
+		global $gRequestManager;
+
+		// サーバ自体のアクセスの場合はチェックなし
+		$senderIp = $gRequestManager->trimServerValueOf('REMOTE_ADDR');
+		$serverIp = $gRequestManager->trimServerValueOf('SERVER_ADDR');
+		if ($senderIp == $serverIp) return true;		// アクセス元と自サーバが同じとき
+			
+		// ユーザ情報がある場合のみチェックを行う
+		if (M3_SESSION_SECURITY_CHECK && isset($userInfo)){
+			// クライアントIP、セキュリティコードをチェック
+			$securityCode = $gRequestManager->getSessionValue(M3_SESSION_CODE);
+			$clientIp = $gRequestManager->getSessionValue(M3_SESSION_CLIENT_IP);
+			$checkSecurityCode = $this->getSessionSecurityCode();
+			$checkClientIp = $this->getClientIp();
+			
+			if ($userInfo->userType >= UserInfo::USER_TYPE_MANAGER){
+				// システム運用可能ユーザのときはクライアントIP、セキュリティコード両方の合致を条件とする
+				if ($securityCode != $checkSecurityCode ||		// セッションのセキュリティコードが合わない場合
+					$clientIp != $checkClientIp){
+					$errMsg = 'セッション情報への不正なアクセスを検出しました。アクセス元IP: ' . $this->getClientIp();
+					$msgDetail = 'アクセスをブロックしました。account=' . $userInfo->account . ', userid=' . $userInfo->userId;
+					$this->gOpeLog->writeUserError(__METHOD__, $errMsg, 2210, $msgDetail);
+					return false;
+				}
+			} else {
+				// システム運用可能ユーザよりも下のレベルの場合はクライアントIPまたはセキュリティコードのどちらかの合致で問題なしとする
+				if ($securityCode != $checkSecurityCode &&		// セッションのセキュリティコードが合わない場合
+					$clientIp != $checkClientIp){
+					$errMsg = 'セッション情報への不正なアクセスを検出しました。アクセス元IP: ' . $this->getClientIp();
+					$msgDetail = 'アクセスをブロックしました。account=' . $userInfo->account . ', userid=' . $userInfo->userId;
+					$this->gOpeLog->writeUserError(__METHOD__, $errMsg, 2210, $msgDetail);
+					return false;
+				}
+			}
+		}
+		return true;
+	}
+	/**
+	 * セキュリティチェック用コード作成
+	 *
+	 * @return string						セキュリティコード
+	 */
+	function _generateSessionSecurityCode()
+	{
+		global $gRequestManager;
+		
+		$agent		= $gRequestManager->trimServerValueOf('HTTP_USER_AGENT');		// クライアントアプリケーション
+		$language	= $gRequestManager->trimServerValueOf('HTTP_ACCEPT_LANGUAGE');	// クライアント認識可能言語
+		$sessionCode = md5($agent . ':' . $language);
+		
+		return $sessionCode;
+	}
+	/**
+	 * セキュリティチェック用コード取得
+	 *
+	 * @return string						セキュリティコード
+	 */
+	function getSessionSecurityCode()
+	{
+		if (!isset($this->_sessionCode)) $this->_sessionCode = $this->_generateSessionSecurityCode();
+		return $this->_sessionCode;
+	}
 	/**
 	 * アクセスログユーザの記録
 	 *
