@@ -1665,8 +1665,16 @@ class WP_Query {
 	 */
 	public function get_posts() {
 		global $gContentApi;
+		global $gRequestManager;
 		
-		// ##### DBからコンテンツを取得 ###
+		// ##### URLパラメータを解析 #####
+		$this->query_vars = array();
+		// ページ番号
+		$pageNo = absint($gRequestManager->trimValueOf('page'));
+		$this->query_vars['paged'] = $pageNo;
+		if ($pageNo > 1) $this->is_paged = true;
+			
+		// ##### DBからコンテンツを取得 #####
 		// コンテンツタイプが設定されていない場合はダミーのWP_Postデータを作成
 		$contentType = $gContentApi->getContentType();
 		if (empty($contentType)){
@@ -1695,8 +1703,13 @@ class WP_Query {
 			$wpPostObj = new WP_Post($post);
 			$this->posts = array($wpPostObj);
 		} else {
-			$gContentApi->setCondition(array(), ''/*現在の言語*/, 10/*最大取得数*/, 1/*ページ番号*/);
+			$gContentApi->setCondition(array(), ''/*現在の言語*/, 0/*最大取得数(デフォルト)*/, $pageNo/*ページ番号*/);
 			$this->posts = $gContentApi->getContentList();
+			
+			// コンテンツ総数を取得
+			$viewCount = $gContentApi->getContentViewCount();		// １ページあたりの表示記事数
+			$this->found_posts = $gContentApi->getContentCount();		// コンテンツ総数
+			$this->max_num_pages = ceil($this->found_posts / $viewCount);		// 総ページ数
 		}
 
 		// Ensure that any posts added/modified via one of the filters above are
@@ -2527,7 +2540,7 @@ class WP_Query {
 	 * @return bool Whether the query is for an existing single post.
 	 */
 	public function is_single( $post = '' ) {
-		if ( !$this->is_single )
+/*		if ( !$this->is_single )
 			return false;
 
 		if ( empty($post) )
@@ -2556,8 +2569,9 @@ class WP_Query {
 			}
 		}
 		return false;
+		*/
+		return $this->is_single;
 	}
-
 	/**
 	 * Is the query for an existing single post of any post type (post, attachment, page, ... )?
 	 *
@@ -2573,12 +2587,14 @@ class WP_Query {
 	 * @return bool Whether the query is for an existing single post of any of the given post types.
 	 */
 	public function is_singular( $post_types = '' ) {
-		if ( empty( $post_types ) || !$this->is_singular )
+/*		if ( empty( $post_types ) || !$this->is_singular )
 			return (bool) $this->is_singular;
 
 		$post_obj = $this->get_queried_object();
 
 		return in_array( $post_obj->post_type, (array) $post_types );
+		*/
+		return $this->is_single || $this->is_page || $this->is_attachment;
 	}
 
 	/**
@@ -2683,6 +2699,7 @@ class WP_Query {
 
 		$id = (int) $post->ID;
 
+		// ##### 現在取得中の記事に関連するユーザ情報を取得する #####
 		$authordata = get_userdata($post->post_author);
 
 		$currentday = mysql2date('d.m.y', $post->post_date, false);
